$set 3 #Configmenu

$ #ConfigOptions
# Instllningar
$ #FocusModel
# Fokusmodell
$ #WindowPlacement
# Fnsterplacering
$ #ImageDithering
# Bilddithering
$ #OpaqueMove
# Ogenomskinlig fnsterfrflyttning
$ #FullMax
# Full maximering
$ #FocusNew
# Fokus p nya fnster
$ #FocusLast
# Fokusera fnster vid skrivbordsbyte
$ #ClickToFocus
# Klicka fr fokus
$ #SloppyFocus
# Hafsig fokus
$ #AutoRaise
# Hj automatiskt
$ #SmartRows
# Smart placering (Rader)
$ #SmartCols
# Smart placering (Kolumner)
$ #Cascade
# Kaskadplacering
$ #LeftRight
# Frn vnster
$ #RightLeft
# Frn hger
$ #TopBottom
# Uppifrn
$ #BottomTop
# Nerifrn
$ #Tabs
# Anvnd Flikar
$ #Icons
# Anvnd Ikoner
$ #TabPlacement
# Flik Placering
$ #TabRotateVertical
# Rotera Vertikala Flikar
$ #SemiSloppyFocus
# Halv hafsig fokus
$ #MaxOverSlit
# Maximize Over Slit
$ #SloppyWindowGrouping
# Hafsig Fnster Gruppering
$ #WorkspaceWarping
# Dra fnster mellan arbetsytor
$ #DesktopWheeling
# ndra arbetsyta med mushjulet
$ #AntiAlias
# Kantutjmning

